@@ -35,6 +35,7 @@ class DesktopCommand(Command):
         super().__init__(config)
         self.command = None
         self.custom_mode = False
+        self.ide_delegate = None
 
     def run(self, path_arg=None):
         self.prepare_run()
@@ -67,7 +68,7 @@ class DesktopCommand(Command):
         if self.custom_mode:
             docker_config.execute = self.command
             docker_config.working_directory = self.config.root_dir
-            docker_config.add_extra_flags({'--tty'})
+            docker_config.pseudo_tty = True
 
             executable = self.config.project_files.find_any_executable()
             exec_args = self.config.project_files.find_any_exec_args()
@@ -78,6 +79,7 @@ class DesktopCommand(Command):
                         "CLICK_EXEC_PARAMS": " ".join(exec_args),
                     })
         else:
+            docker_config.pseudo_tty = self.config.debug_gdb
             docker_config.execute = self.determine_executable(
                 self.find_desktop_file()
             )
@@ -246,6 +248,10 @@ class DesktopCommand(Command):
 
     def run_app(self):
         docker_config = self.setup_docker()
+
+        if self.ide_delegate is not None:
+            self.ide_delegate.before_run(self.config, docker_config)
+
         command = docker_config.render_command()
         logger.debug(command)
 
