@@ -207,7 +207,7 @@ class ProjectConfig(object):
             if self.is_arch_agnostic():
                 self.config["arch"] = "all"
                 logger.debug('Architecture set to "all" because builder "{}" is architecture agnostic'.format(self.config['builder']))
-            elif self.is_desktop_mode():
+            elif self.is_desktop_mode() or self.is_ide_command():
                 self.config["arch"] = "amd64"
                 logger.debug('Architecture set to "amd64" because of desktop mode.')
             elif self.config["restrict_arch"]:
@@ -231,9 +231,6 @@ class ProjectConfig(object):
             raise ClickableException('There is currently no support for architecture  "{}"'.format(self.config['arch']))
         self.config['arch_triplet'] = Constants.arch_triplet_mapping[self.config['arch']]
 
-        if self.host_arch not in Constants.container_mapping:
-            raise ClickableException('Clickable currently does not have docker images for your host architecture "{}"'.format(self.host_arch))
-
         if not self.config['kill']:
             if self.config['builder'] == Constants.CORDOVA:
                 self.config['kill'] = 'cordova-ubuntu'
@@ -254,12 +251,18 @@ class ProjectConfig(object):
     def setup_image(self):
         self.set_build_arch()
 
-        if self.needs_docker_image():
+        if self.needs_clickable_image():
             self.check_nvidia_mode()
 
+            if self.host_arch not in Constants.container_mapping:
+                raise ClickableException('Clickable currently does not have docker images for your host architecture "{}"'.format(self.host_arch))
+
             if self.use_nvidia and not self.build_arch.endswith('-nvidia'):
                 self.build_arch = "{}-nvidia".format(self.build_arch)
 
+            if self.is_ide_command():
+                self.build_arch = "{}-ide".format(self.build_arch)
+
             container_mapping_host = Constants.container_mapping[self.host_arch]
             if ('16.04', self.build_arch) not in container_mapping_host:
                 raise ClickableException('There is currently no docker image for 16.04/{}'.format(self.build_arch))
@@ -559,20 +562,27 @@ class ProjectConfig(object):
         return self.config["builder"] in Constants.arch_agnostic_builders
 
     def is_desktop_mode(self):
-        return bool(set(['desktop', 'ide', 'test']).intersection(self.commands))
+        return bool(set(['desktop', 'test']).intersection(self.commands))
+
+    def is_ide_command(self):
+        return "ide" in self.commands
 
     def is_build_cmd(self):
         return (self.is_desktop_mode() or
-                set(['build', 'build-libs', 'clean-build']).intersection(self.commands))
+                bool(set(['build', 'build-libs', 'clean-build']).intersection(self.commands)))
 
     def needs_builder(self):
         return self.is_build_cmd()
 
-    def needs_docker_image(self):
+    def needs_clickable_image(self):
         return (not self.is_custom_docker_image and
                 not self.container_mode and
                 (self.is_build_cmd() or
-                    set(['setup', 'run', 'ide', 'update', 'gdb', 'gdbserver', 'review']).intersection(self.commands)))
+                    bool(set(['setup', 'run', 'ide', 'update', 'gdb', 'gdbserver', 'review']).intersection(self.commands))))
+
+    def needs_docker(self):
+        return (not self.container_mode and
+                (self.needs_clickable_image() or self.is_custom_docker_image))
 
     def check_clickable_version(self):
         if self.config['clickable_minimum_required']:
